import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, message, Table, Divider, Tag, Pagination, Modal, DatePicker } from 'antd';
import router from 'umi/router';
import apis from '../../../../services/apis';
import request from '../../../../utils/request';
import AuthButton from '../../../../components/AuthButton';
import WxDictSelect from '@/components/SelectButton/WxDictSelect';
import moment from 'moment';


const date = {
    startDate: moment().year(1000).hours(0).minutes(0).seconds(0).milliseconds(0).toDate(),
    endDate: moment().year(3000).hours(0).minutes(0).seconds(0).milliseconds(0).toDate()
  }
  
  const header = props => {
  
    const [data, setData] = useState({})

    const activityId = props.id
    const activityType = props.type
  
    useEffect(() => {
      console.log(activityId, activityType)
      getList({pageNum: 1, pageSize: 10 })
  
    }, [])
  
    const getList = params => {
      console.log(params)
      request({ ...apis.activityDataStatis.activityShareNum, params: {...params, activityId: activityId, activityType: activityType,...date  }}).then( data=> {
        console.log(data)
        props.getData()
        setData(data)
      }).catch(e=>{
        console.log(e)
      })
    }
   
    const columns = [
        {
          title: '分享者姓名',
          dataIndex: 'sharePersonName',
          key: 'sharePersonName',
        },
        {
          title: '分享者类型',
          dataIndex: 'shareType',
          key: 'shareType',
          render: (text, records) => {
            if (records.sharePersonType === 'drift') { return '游客' }
            if (records.sharePersonType === 'customer') { return '普通客户' }
            if (records.sharePersonType === 'Realty Consultant') { return '置业顾问' }
          },
        },
        {
          title: '分享时间',
          dataIndex: 'shareTime',
          key: 'shareTime',
          render: (x, row) => <><span>{`${moment(row.shareTime).format('YYYY-MM-DD HH:mm:ss')}`}</span></>,
        },
        {
          title: '分享者电话',
          dataIndex: 'sharePersonPhone',
          key: 'sharePersonPhone',
        },
        // {
        //   title: '访问人数',
        //   dataIndex: 'visitPersonNum',
        //   key: 'visitPersonNum',
        // },
      ]

    function handleReset() {
        props.form.resetFields();
        getList({ pageNum: 1, pageSize: 10 })
    }

    const changePageNum = pageNumber => {
        getList({ pageNum: pageNumber, pageSize: 10, ...props.form.getFieldsValue() })
    }

    const handleSubmit = e => {
      e.preventDefault();
      props.form.validateFields((err, values) => {
        if (!err) {
         
          getList({ pageNum: 1, pageSize: 10, ...values })
        }
      });
    }


  
    const exportActivityStats = () => {
      
      request({ ...apis.activityDataStatis.activityShareNumExport, params: {activityId: activityId, activityType: activityType,...props.form.getFieldsValue(),...date} }).then(data => {
        if (!data) {
          return
        }
        const url = window.URL.createObjectURL(new Blob([data]))
          const link = document.createElement('a')
          link.style.display = 'none'
          link.href = url
          link.setAttribute('download', '访问统计.xlsx')
          document.body.append(link)
          link.click()
      }).catch()
    }
  

    const { getFieldDecorator } = props.form
    return <>
        <div>
            <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>
                <Form.Item style={{ marginTop: '20px', marginBottom: '20px' }}>
                    {getFieldDecorator('sharePersonType')(
                        <Select placeholder="分享者类型" style={{ width: 150, marginLeft: '20px' }}>
                            <Option value="">全部</Option>
                            <Option value="drift">游客</Option>
                            <Option value="customer">普通客户</Option>
                            <Option value="Realty Consultant">置业顾问</Option>
                        </Select>
                    )}
                </Form.Item>
                <Form.Item style={{ marginTop: '20px', marginBottom: '20px' }}>
                    {getFieldDecorator('sharePersonPhone')(<Input placeholder="分享者电话" />)}
                </Form.Item>
                <Form.Item style={{ marginTop: '20px', marginBottom: '20px' }}>
                    {getFieldDecorator('sharePersonName')(<Input placeholder="分享者姓名" />)}
                </Form.Item>
                <Form.Item style={{ marginTop: '20px', marginBottom: '20px' }}>
                    <Button type="primary" htmlType="submit" style={{ marginLeft: '30px' }}> 查询</Button>
                    <Button onClick={handleReset} style={{ marginLeft: '30px' }}>重置</Button>
                </Form.Item>
            </Form>
            <div>
                <Button type="primary" style={{ float: 'right', marginBottom: '20px', zIndex: 1 }} onClick={exportActivityStats}>导出</Button>
            </div>
            <Table style={{ marginTop: '30px' }} dataSource={data.records} columns={columns} pagination={false} rowKey="activityList" />
            <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
                <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={changePageNum} current={data.current} />
            </div>
        </div>
    </>
}

const WrappedTypeForm = Form.create()(header);
export default WrappedTypeForm